* Output options: all can be turned on/off by adding or removing the NO;
* page number, date, centering, or page breaks, page length and width;
  OPTIONS NOnumber NOdate NOcenter FormDlim=' ' PageSize=MAX LineSize=MAX;
* Eliminate SAS default titles and names of tables in output (TRACE ON to show);
  TITLE; ODS TRACE OFF;

***********************************************************************************;
*******   MACRO PROGRAMS TO AUTOMATE CALCULATIONS FOR CHAPTER 2 EXAMPLE     *******;
*******               NOTHING IN HERE NEEDS TO BE CHANGED                   *******;
***********************************************************************************;

* To use ModelR2 macro for chapter 2 cross-sectional models;
* CovFewer =    name of covparms table for baseline empty model;
* CovFewer =    name of covparms table for nested model;
* CovMore =     name of covparms table for comparison model;
%MACRO ModelR2(CovBase=,CovFewer=,CovMore=);
DATA &CovBase.;  LENGTH Name $30.; SET &CovBase.;  Name="&CovBase." ;  
    CALL SYMPUT('EmptyEst',estimate);  RUN;
DATA &CovFewer.; LENGTH Name $30.; SET &CovFewer.; Name="&CovFewer."; RUN;
DATA &CovMore.;  LENGTH Name $30.; SET &CovMore.;  Name="&CovMore.";  RUN;
DATA CovCompare; LENGTH Name $30.; SET &CovBase. &CovFewer. &CovMore.; RUN;
DATA CovCompare; SET CovCompare;  
    R2_from_Base=(&EmptyEst.-Estimate)/&EmptyEst.;
    R2_Increment=R2_from_Base-LAG1(R2_from_Base); 
    IF _N_=2 THEN R2_Increment=.; RUN;
DATA CovCompare; SET CovCompare; 
    IF CovParm IN("UN(2,1)","UN(3,1)","UN(4,1)","UN(3,2)","UN(4,2)","UN(4,3)") 
    THEN DELETE; RUN;
TITLE9 "R2 (% Reduction) Overall and for &CovFewer. vs. &CovMore.";
PROC PRINT NOOBS DATA=CovCompare; RUN; TITLE9;
%MEND ModelR2;

***********************************************************************************;
*******             BEGIN DATA MANIPULATION FOR CHAPTER 2 EXAMPLE           *******;
*******                  CHANGE "filesave" to your directory                *******;
***********************************************************************************;

* Defining global variable for file location to be replaced in code below;
  %LET filesave= C:\Dropbox\14_SPLH861\861_Example1;
* Location for SAS files for these models (uses macro variable filesave);
  LIBNAME filesave "&filesave.";

* Import chapter 2 example data into work library;
DATA work.Chapter2; SET filesave.SAS_Chapter2;
* Center continuous predictors;
age85 = age - 85;
grip9 = grip - 9;
* Re-coding sex so women are reference (unnecessary);
     IF sexMW=0 THEN sexwm=1; 
ELSE IF sexMW=1 THEN sexwm=0; 
* Creating all possible contrasts for dementia groups;
     IF demgroup=1 THEN DO; demNF=0; demNC=0; END;
ELSE IF demgroup=2 THEN DO; demNF=1; demNC=0; END;
ELSE IF demgroup=3 THEN DO; demNF=0; demNC=1; END;
* Labeling new variables;
LABEL   
age85=  "age85: Age in Years (0=85)"
grip9=  "grip9: Grip Strength in Pounds (0=9)"
sexwm=  "sexwm: Sex (0=Women, 1=Men)"
demNF=  "demNF: Dementia Contrast for None=0 vs Future=1"
demNC=  "demNC: Dementia Contrast for None=0 vs Current=1";
RUN;

***********************************************************************************;
*******                       BEGIN EXAMPLE 1 MODELS                        *******;
***********************************************************************************;

* Open output directory to save results to;
ODS RTF FILE="&filesave.\SAS_Example1_Output.rtf" STYLE=HTMLBlue STARTPAGE=NO;

TITLE1 "Chapter 2: Descriptive Statistics for Example Variables";
PROC MEANS DATA=work.Chapter2; VAR age grip cognition; RUN;
PROC FREQ  DATA=work.Chapter2; TABLE sexMW*demgroup; RUN;
PROC CORR  DATA=work.Chapter2; VAR age grip sexMW cognition; RUN;
TITLE1;

TITLE1 'Eq 2.3: Empty Means Model';
PROC MIXED DATA=work.Chapter2 COVTEST NOCLPRINT NAMELEN=100 IC METHOD=REML;
     MODEL cognition =  / CHISQ SOLUTION CL DDFM=BW;
     ODS OUTPUT CovParms=CovEmpty;
RUN; TITLE1;
 
TITLE1 'Eq 2.4: Adding Age 0=85';
PROC MIXED DATA=work.Chapter2 COVTEST NOCLPRINT NAMELEN=100 IC METHOD=REML;
     MODEL cognition = age85 / CHISQ SOLUTION CL DDFM=BW;
     ODS OUTPUT CovParms=CovAge;
RUN; TITLE1;
     * Call macro to calculate R2 for overall model;
       %ModelR2(CovBase=CovEmpty, CovFewer=CovEmpty, CovMore=CovAge);
 
TITLE1 'Eq 2.6: Adding Grip 0=9';
PROC MIXED DATA=work.Chapter2 COVTEST NOCLPRINT NAMELEN=100 IC METHOD=REML;
     MODEL cognition = age85 grip9 / CHISQ SOLUTION CL DDFM=BW;
     CONTRAST "Model R2 F-Test" age85 1, grip9 1 / CHISQ;
     ODS OUTPUT CovParms=CovGrip;
RUN; TITLE1;
     * Call macro to calculate R2 for overall model;
       %ModelR2(CovBase=CovEmpty, CovFewer=CovAge, CovMore=CovGrip);
 
TITLE1 'Eq 2.7: Adding Sex 0=M 1=W';
PROC MIXED DATA=work.Chapter2 COVTEST NOCLPRINT NAMELEN=100 IC METHOD=REML;
     MODEL cognition = age85 grip9 sexMW / CHISQ SOLUTION CL DDFM=BW;
     CONTRAST "Model R2 F-Test" age85 1, grip9 1, sexMW 1 / CHISQ;
     ODS OUTPUT CovParms=CovSex;
     ESTIMATE "Intercept for Women" intercept 1 sexMW 1 / CL;
RUN; TITLE1;
     * Call macro to calculate R2 for overall model;
       %ModelR2(CovBase=CovEmpty, CovFewer=CovGrip, CovMore=CovSex);

TITLE1 'Eq 2.8: Adding Dementia Group';
TITLE2 'Using Manual Group Contrasts so Reference=None';
PROC MIXED DATA=work.Chapter2 COVTEST NOCLPRINT NAMELEN=100 IC METHOD=REML;
     MODEL cognition = age85 grip9 sexMW demNF demNC / CHISQ SOLUTION CL DDFM=BW;
     ODS OUTPUT CovParms=CovDem;
	 CONTRAST "Model R2 F-Test" age85 1, grip9 1, sexmw 1, demNF 1, demNC 1;
     CONTRAST "Omnibus F-Test for Dementia Group" demNF 1, demNC 1;
     * Request group means (hold age=85, grip=9, men);
     ESTIMATE "Intercept for None Group"    intercept 1 demNF 0 demNC 0 / CL;
     ESTIMATE "Intercept for Future Group"  intercept 1 demNF 1 demNC 0 / CL;
     ESTIMATE "Intercept for Current Group" intercept 1 demNF 0 demNC 1 / CL;
     * Request group differences;
     ESTIMATE "None   vs. Future Group"   demNF  1 demNC 0 / CL;
     ESTIMATE "None   vs. Current Group"  demNF  0 demNC 1 / CL;
     ESTIMATE "Future vs. Current Group"  demNF -1 demNC 1 / CL;
RUN; TITLE1; TITLE2;
     * Call macro to calculate R2 for overall model;
       %ModelR2(CovBase=CovEmpty, CovFewer=CovSex, CovMore=CovDem);

* Close output;
ODS RTF CLOSE;
